;;; init.el --- .Emacs Configuration -*- lexical-binding: t -*-
;;; Commentary:
;;
;; Emacs!!!

;;; Code:
(package-initialize)

(when (version<= emacs-version "24")
  (error "This is made form Emacs >=24"))

(defconst emacs-start-time (current-time))
(add-to-list 'load-path (expand-file-name "~/.emacs.d/modules/" user-emacs-directory))

;;; Raise garbage collection threshold after init
(add-hook 'after-init-hook
	  (lambda () (setq gc-cons-threshold local/gc-cons-threshold)))

;;; Custom variables
(setq custom-file (expand-file-name "custom.el" user-emacs-directory))
;;; Custom settings
(setq settings-file (expand-file-name "settings.el" user-emacs-directory))

;;; Loads settings file
(when (file-exists-p custom-file)
  (load settings-file))
;;;------------------------------
;;; Features
;;;------------------------------
;;; https://stackoverflow.com/questions/2816019/in-lisp-avoid-cannot-open-load-file-when-using-require
(require 'init-security nil 'noerror)
(require 'init-elpa nil 'noerror)
;; theme
(require 'init-theme nil 'noerror)
;; Utils
(require 'init-utils nil 'noerror)
;; GUI
(require 'init-nlinum nil 'noerror)
(require 'init-gui nil 'noerror)
(require 'init-editing-utils nil 'noerror)
(require 'init-diminish nil 'noerror)
(require 'init-ecb nil 'noerror)
(require 'init-modeline nil 'noerror)
(require 'init-indent-guides nil 'noerror)
(require 'init-icons nil 'noerror)
(require 'init-neotree nil 'noerror)
;; Tools
(require 'init-flycheck nil 'noerror)
(require 'init-whitespace nil 'noerror)
(require 'init-emmet-mode nil 'noerror)
(require 'init-nginx nil 'noerror)
(require 'init-git nil 'noerror)
;;(require 'init-editorconfig nil 'noerror)
;; Languages
(require 'init-ccc nil 'noerror)
(require 'init-crystal nil 'noerror)
(require 'init-html nil 'noerror)
(require 'init-markdown nil 'noerror)
(require 'init-php nil 'noerror)
(require 'init-python nil 'noerror)
(require 'init-pkgbuild nil 'noerror)
(require 'init-less nil 'noerror)
(require 'init-sass nil 'noerror)
(require 'init-scss nil 'noerror)
(require 'init-yaml nil 'noerror)
;; Plus
(require 'init-rainbow nil 'noerror)
(require 'init-web-mode nil 'noerror)
(require 'init-ready nil 'noerror)
(require 'init-dokuwiki nil 'noerror)

;;; Loads custom file
(when (file-exists-p custom-file)
  (load custom-file))

(when window-system
  (let ((elapsed (float-time (time-subtract (current-time)
                                            emacs-start-time))))
    (message "[STARTUP] Loading %s ... done (%.3fs)" load-file-name elapsed)))

(provide 'init)
;; Local Variables:
;; byte-compile-warnings: (not free-vars)
;; End:
;;; init.el ends here
